#
# spec file for package nvidia-open-driver-G06-signed
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define gfx_version 570.172.08
%define cuda_version 575.57.08

%global flavor %{?nil}
%if "%{flavor}" == "cuda"
 %if 0%{?suse_version} > 1600
ExclusiveArch:  do_not_build
 %endif
%{bcond_without cuda}
%define mykind cuda
%define otherkind gfx
%else
%define mykind gfx
%define otherkind cuda
%endif
%if %{undefined kernel_module_directory}
%if 0%{?suse_version} >= 1550
%define kernel_module_directory /usr/lib/modules
%else
%define kernel_module_directory /lib/modules
%endif
%endif

%if 0%{?suse_version} >= 1550 || 0%{?sle_version} >= 150400
%define compress_modules zstd
%else
%define compress_modules xz
%endif
Name:           nvidia-open-driver-G06-signed%{?with_cuda:-cuda}
VCS: https://src.suse.de/SLFO-pool/nvidia-open-driver-G06-signed?trackingbranch=main#6e5f81749873eaf5709ced030ff2031321cba9030364ba568c2214cff6cc44df
%if %{with cuda}
Version:        %{cuda_version}
%else
Version:        %{gfx_version}
%endif

Release:        160000.1.3
Summary:        NVIDIA open kernel module driver for GeForce 16 series (GTX 16xx) and newer
License:        GPL-2.0-only AND MIT
Group:          System/Kernel
URL:            https://github.com/NVIDIA/open-gpu-kernel-modules/
#Source0:        https://github.com/NVIDIA/open-gpu-kernel-modules/archive/refs/tags/%{version}.tar.gz#/open-gpu-kernel-modules-%{version}.tar.gz
Source0:        open-gpu-kernel-modules-%{version}.tar.gz
# This is defined at build, not for 'osc service run download_files` or
# factory_auto. This both sources are seen outside of the build but only
# the matching one will be included in the srpm for the respective flavor.
%if %{undefined linux_arch}
Source16:       https://github.com/NVIDIA/open-gpu-kernel-modules/archive/refs/tags/%{cuda_version}.tar.gz#/open-gpu-kernel-modules-%{cuda_version}.tar.gz
Source18:       pci_ids-%{cuda_version}
%endif
Source1:        my-find-supplements
Source2:        pci_ids-%{version}
Source3:        kmp-filelist
Source7:        preamble
Source8:        json-to-pci-id-list.py
# Generate:
# CUDA_VER=12.5.1; DRIVER_VER=%version; ARCH=...
# mkdir tmp
# wget https://developer.download.nvidia.com/compute/cuda/<cuda_ver>/local_installers/cuda_${CUDA_VER}_${DRIVER_VER}_linux.run -P ./tmp
# sh tmp/cuda_${CUDA_VER}_${DRIVER_VER}_linux.run --extract=$(pwd)/tmp
# cd tmp; sh ./NVIDIA-Linux-$ARCH-$DRIVER_VER.run -x; cd -
# ./json-to-pci-id-list.py --skiplegacy --kernelopen tmp/NVIDIA-Linux-${ARCH}-${DRIVER_VER}/supported-gpus/supported-gpus.json pci_ids-supported-$DRIVER_VER
Source10:       pci_ids-supported
Source11:       pesign-copy-sources
Source12:       pesign-spec-macros
Source14:       group-source-files.pl
Source15:       kmp-trigger.sh
BuildRequires:  %{kernel_module_package_buildreqs}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  kernel-source
BuildRequires:  kernel-syms
BuildRequires:  perl-Bootloader
BuildRequires:  pesign-obs-integration
BuildRequires:  zstd
%ifnarch aarch64
# limit build of -azure flavor to SP6
%if (!0%{?is_opensuse} && (0%{?sle_version} >= 150600 && 0%{?sle_version} < 150700))
BuildRequires:  kernel-syms-azure
%endif
%endif
%if 0%{?is_opensuse} && 0%{?suse_version} >= 1699
# build KPMs for kernel-longterm in Factory
BuildRequires:  kernel-syms-longterm
%endif
ExclusiveArch:  x86_64 aarch64

%if 0%{!?kmp_template_name:1}
%define kmp_template_name /usr/lib/rpm/kernel-module-subpackage
%endif
%if 0%{!?_builddir:1}
%define _builddir /home/abuild/rpmbuild/BUILD
%endif

%(cat %kmp_template_name > %_builddir/nvidia-kmp-template)
%(echo "%triggerin -p /bin/bash -n %%{-n*}-kmp-%1 -- nvidia-common-G06 = %{version}"      >> %_builddir/nvidia-kmp-template)
%(cat %_sourcedir/kmp-trigger.sh                                                          >> %_builddir/nvidia-kmp-template)
#  NOTE: kernel_module_package macro affects preference among nvidia, nvidia-open
#  and nvidia-open-signed driver by adding:
# Enhance: kernel-%FLAVOR
%define x_flavors rt
%kernel_module_package -n %{name} -t %_builddir/nvidia-kmp-template -f %_sourcedir/kmp-filelist -p %_sourcedir/preamble -x %x_flavors
%{expand:%(
      for f in %{flavors_to_build}; do \
	  echo "%package -n %{name}-${f}-devel"; \
	  echo "Summary:      Devel Package to %name"; \
	  echo "%description -n %{name}-${f}-devel"; \
	  echo "Provide build requiresments to build against %{name}"; \
	  echo "%files -n %{name}-${f}-devel -f files-${f}"; \
      done)}

%package -n nv-prefer-signed-open-driver
%define version_major %(i=%{version}; echo ${i%%%%.*})
Summary:        Prefer the signed open driver when installing CUDA
Requires:       nvidia-open-driver-G06-signed-cuda-kmp
# This avoids the package being uninstallable when the CUDA repo is unavaliable preventing problems in staging
# Hard code version 555.42.06 as this requires is only needed for this version
# but since this meta package should apply to all versions.
Requires:       ( nvidia-compute-G06 = 555.42.06 if ( cuda-drivers = 555.42.06 or cuda-drivers-%version_major = 555.42.06) )

%description -n nv-prefer-signed-open-driver
By installing this package, the signed NVIDIA open driver built by SUSE will be preferred during installation
of CUDA components.
Simply run: `zypper install --no-recommends cuda-runtime-<version> nv-prefer-signed-open-driver`

%if %{with cuda}
%files -n nv-prefer-signed-open-driver
%endif
## create hardware supplements for manual builds
%{load:%{SOURCE12}}

# newer rpmbuilds attach the kernel version and the major part of release to %%pci_id_file of the __kmp_supplements script
# boo#1190210
%define kbuildver %(rpm -q --queryformat '%%{VERSION}_%%{RELEASE}' kernel-syms | sed -n 's/\\(.*\\)\\.[0-9]\\{1,\\}/\\1/p')

%description
This package provides the open-source NVIDIA kernel module driver
for GeForce 16 series (GTX 16xx) and newer GPUs, i.e. Turing GPU family
and newer (Turing, Ampere, Ada Lavelace, Hopper, Blackwell, ...).

%prep
%autosetup -p1 -n open-gpu-kernel-modules-%{version}

set -- *
mkdir source
mv "$@" source/
mkdir obj

pushd %_sourcedir
chmod 755 my-find-supplements*
%if %{with cuda}
# make sure it's empty for -cuda variant
rm  pci_ids-%{version}
touch  pci_ids-%{version}
%endif
# symlink the %pci_id_file to the one, that rpmbuild generates, to enable my-find-supplement to succeed properly
# boo#1190210
ln -sv pci_ids-%{version} pci_ids-%{version}_k%{kbuildver}
popd

%build
%ifarch aarch64
# -Wall is upstream default
export CFLAGS="-Wall -mno-outline-atomics"
%endif
# kernel was compiled using a different compiler
export CC=gcc
# no longer needed and never worked anyway (it was only a stub) [boo#1211892]
export NV_EXCLUDE_KERNEL_MODULES=nvidia-peermem
for flavor in %{flavors_to_build}; do
        rm -rf obj/$flavor
        cp -r source obj/$flavor
	pushd obj/$flavor
	if [ -d /usr/src/linux-$flavor ]; then
	  export SYSSRC=/usr/src/linux-$flavor
	else
	  export SYSSRC=/usr/src/linux
	fi
	export SYSOUT=/usr/src/linux-obj/%_target_cpu/$flavor
        make %{?_smp_mflags} modules DATE="date -d @${SOURCE_DATE_EPOCH:-$(date +%s)}" NV_BUILD_HOST=OBS HOSTNAME=OBS
        popd
done

%install
export BRP_PESIGN_FILES="*.ko"
export BRP_PESIGN_COMPRESS_MODULE=%{compress_modules}
export INSTALL_MOD_PATH=%{buildroot}
export INSTALL_MOD_DIR=%{kernel_module_package_moddir}/%{name}-%{version}
for flavor in %{flavors_to_build}; do
	pushd obj/$flavor
	if [ -d /usr/src/linux-$flavor ]; then
	  export SYSSRC=/usr/src/linux-$flavor
	else
	  export SYSSRC=/usr/src/linux
	fi
	export SYSOUT=/usr/src/linux-obj/%_target_cpu/$flavor
        make modules_install
	popd
done

for flavor in %{flavors_to_build}; do
    mkdir -p %{buildroot}%{_prefix}/src/kernel-modules/nvidia-%{version}-${flavor}
    cp -r source/kernel-open/* %{buildroot}%{_prefix}/src/kernel-modules/nvidia-%{version}-${flavor}
    echo %dir %{_prefix}/src/kernel-modules > files-${flavor}
    perl %{S:14} -L %{buildroot}%{_prefix}/src/kernel-modules/nvidia-%{version}-${flavor} | sed -e "s@%{buildroot}@@" | sort -u >> files-${flavor}
    %fdupes -s %{buildroot}%{_prefix}/src/kernel-modules/nvidia-%{version}-${flavor}
done

%changelog
* Fri Jul 11 2025 sndirsch@suse.com
- update non-CUDA variant to 570.172.08 (boo#1246327)
- supersedes
  * 0003-nv-dmabuf-Inline-dma_buf_attachment_is_dynamic.patch
  * 0004-nvidia-uvm-Disable-SVA-support-for-6.16.patch
- update pci_ids-supported
* Mon Jul  7 2025 sndirsch@suse.com
- empty pci_ids-570.169; PCI ID hardware Supplements get moved to
  gfx repository to package nvidia-open-driver-G06-signed-kmp-meta
  (boo#1246010)
- remove 60-nvidia-$flavor.conf, since driver no longer gets
  autoselected without gfx/cuda repositories present and so we no
  longer need to disable it by default (boo#1246010)
* Tue Jun 24 2025 sndirsch@suse.com
- 0003-nv-dmabuf-Inline-dma_buf_attachment_is_dynamic.patch
  0004-nvidia-uvm-Disable-SVA-support-for-6.16.patch
  * buildfixes against Kernel 6.16 picked up from
    https://github.com/CachyOS/CachyOS-PKGBUILDS.git
  - -> nvidia/nvidia-utils
* Sun Jun 15 2025 sndirsch@suse.com
- update non-CUDA variant to 570.169 (boo#1244614)
* Wed Jun 11 2025 sndirsch@suse.com
- 60-nvidia-$flavor.conf
  * Don't try to load the driver if config and GSP firmware files are
    not available. Otherwise let the default install rule
    'install nvidia-drm /sbin/modprobe --ignore-install nvidia-drm' of
    50-nvidia.conf win, which comes together with config and GSP
    firmware files (package nvidia-common-G06).
* Mon Jun  9 2025 bwiedemann@suse.com
- Drop persistent-nvidia-id-string.patch - solved via make params instead
* Fri Jun  6 2025 sndirsch@suse.com
- update CUDA variant to 575.57.08
- supersedes persistent-nvidia-id-string.patch
* Wed May 14 2025 sndirsch@suse.com
- update non-CUDA variant to 570.153.02 (boo#1243192)
* Fri May  2 2025 sndirsch@suse.com
- disabled unsupported -rt flavor (bsc#1242054)
* Fri Apr 18 2025 sndirsch@suse.com
- update CUDA variant to 570.133.20
* Tue Apr 15 2025 sndirsch@suse.com
- update non-CUDA variant to 570.144 (boo#1241231)
* Mon Mar 31 2025 sndirsch@suse.com
- limit build of -azure flavor to SP6
* Sat Mar 15 2025 sndirsch@suse.com
- update non-CUDA variant to 570.133.07 (bsc#1239653)
* Sat Mar  8 2025 sndirsch@suse.com
- removed obsolete kernel-firmware-nvidia-gspx-G06-cuda; firmware
  has moved to nvidia-common-G06 and
  kernel-firmware-nvidia-gspx-G06 is no longer available either
  (boo#1239139)
* Tue Mar  4 2025 sndirsch@suse.com
- update CUDA variant to 570.124.06
* Tue Feb 25 2025 sndirsch@suse.com
- update non-CUDA variant to 570.124.04 (boo#1237585)
* Mon Feb 24 2025 sndirsch@suse.com
- update non-CUDA variant to 570.124.02 (boo#1237585)
* Sun Feb 23 2025 rfrohl@suse.com
- explicitly enable KMP for kernel-longterm: this will be needed
  for the transition period, until all KMPs are enabled
* Tue Feb 18 2025 eich@suse.com
- In the module install path revert the order of the 'updates'
  subdirectory and the package name & version. This satisfies
  the kmp dependency checker (boo#1237308).
* Tue Feb  4 2025 eich@suse.com
- Add a directory identifying the KMP and its version to the module
  install path - i.e.:
  <kernel_version>/nvidia-open-driver-G06-signed-<version>/updates
  instead of:
  <kernel_version>/updates
  This avoids conflicts when a new version is built against the
  same kernel release.
* Mon Feb  3 2025 sndirsch@suse.com
- fixed build against openSUSE:Factory by defining %%_builddir
  if needed (boo#1236746)
* Mon Feb  3 2025 sndirsch@suse.com
- no longer try to patch %%post/%%postun; no changes needed any longer
- trigger script needs to be triggered now by nvidia-common-G06,
  which replaced kernel-firmware-nvidia-gspx-G06{,-cuda} packages
* Mon Feb  3 2025 sndirsch@suse.com
- fixed version of 'Provides: nvidia-open-signed-kmp = <version>'
  of nvidia-open-signed-cuda-kmp in preamble file
- fixed
  warning: File listed twice: /usr/src/kernel-modules/nvidia-570.86.16-default
* Tue Jan 28 2025 sndirsch@suse.com
- update non-CUDA variant to 570.86.16 (boo#1236658)
- supersedes aarch64-TW-buildfix.patch
- supersedes set-FOP_UNSIGNED_OFFSET-for-nv_drm_fops.fop_flags.patch
* Mon Jan 27 2025 sndirsch@suse.com
- Update to 565.77
- non-CUDA variant:
  * get rid of modproee.d and dracut.cd files and udev magic;
    instead require nvidia-common-G06
  * Supplements: switch to really supported devices; not only the
    initially supported ones without graphical output
- update non-CUDA and CUDA variant to 570.86.15
* Wed Jan 22 2025 sndirsch@suse.com
- preamble: let -cuda KMP conflict with no-cuda variants < 550.135
  (bsc#1236191)
* Tue Jan 14 2025 sndirsch@suse.com
- Update to 550.144.03 (bsc#1235461, boo#1235871)
  * fixes CVE-2024-0131, CVE-2024-0147, CVE-2024-0149,
    CVE-2024-0150, CVE-2024-53869
* Sat Jan  4 2025 sndirsch@suse.com
- set-FOP_UNSIGNED_OFFSET-for-nv_drm_fops.fop_flags.patch
  * needed for Kernel 6.12 for 565.57.01 driver; already fixed
    for 550.142
  - -> https://forums.developer.nvidia.com/t/patch-for-565-57-01-linux-kernel-6-12/313260
* Tue Dec 17 2024 sndirsch@suse.com
- Update to 550.142 (boo#1234675)
* Tue Dec 17 2024 sndirsch@suse.com
- for SLE Micro 6.x use
  '%%if 0%%{?suse_version} == 1600 && !0%%{?is_opensuse}'; SLE16
  doesn't set %%sle_version and SLE Micro 6.x is already SLE16!
* Wed Dec 11 2024 sndirsch@suse.com
- Do not set %%{?linux_make_arch} for running make modules/modules-install
- supersedes 550.135.patch
* Thu Dec  5 2024 sndirsch@suse.com
- obsolete <=560.35.03 -cuda KMPs; mistakenly we released
  560.35.03 for SP4 ...
* Wed Dec  4 2024 eich@suse.com
- Make sure the correct FW package is installed on non-CUDA.
* Tue Dec  3 2024 sndirsch@suse.com
- kmp-trigger.sh:
  * avoid to return with exit code != 0 if modules could not be
    unloaded for some reason
* Sat Nov 30 2024 sndirsch@suse.com
- only obsolete 555 CUDA driver/firmware packages
* Sat Nov 30 2024 sndirsch@suse.com
- preamble:
  no longer need to provide nvidia-open-driver-G06-kmp because
  since 565.57.01 to the list of requires of nvidia-compute-G06
  the -signed packages has been added
* Sat Nov 30 2024 sndirsch@suse.com
- For CUDA update version to 565.57.01
* Fri Nov 29 2024 eich@suse.com
- Add 'dummy' firmware package on SLE to work around update
  issues. On SLE, the firmware is installed directly from
  an NVIDIA-hosted repo.
* Thu Nov 28 2024 sndirsch@suse.com
- preamble
  * resolve self conflicts of -cuda KMP during update by adding
    obsoletes to older versions (boo#1233332)
* Mon Nov 25 2024 sndirsch@suse.com
- fixed my wrong patch 550.135.patch I introduced right below;
  it fixed x86_64 build more-or-less accidently but broke aarch64
  build completely ...
* Mon Nov 25 2024 eich@suse.com
- Improve handling of conflicts between different flavors
  (gfx vs. CUDA) (bsc#1233332).
* Mon Nov 25 2024 sndirsch@suse.com
- Update to 550.135 (boo#1233673)
- 550.135.patch:
  * fixes wrong logic for checking supported architectures
* Mon Nov 11 2024 sndirsch@suse.com
- kmp-trigger.sh:
  * avoid to return with exit code != 0 if no modules are loaded
* Wed Oct 23 2024 sndirsch@suse.com
- Update to 550.127.05 (boo#1232057)
  * Fixed a bug which could cause applications using GBM to crash
    when running with nvidia-drm.modeset=0.
* Mon Oct 21 2024 sndirsch@suse.com
- cuda-flavor
  provide also nvidia-open-driver-G06-kmp-$flavor = %%version to
  workaround broken cuda-drivers
* Fri Oct 18 2024 sndirsch@suse.com
- For CUDA update version to 560.35.03
- supersedes kernel-6.10.patch
* Fri Oct 18 2024 sndirsch@suse.com
- cuda-flavor
  * provide nvidia-open-driver-G06-kmp = %%version to workaround
    broken cuda-drivers
- nv-prefer-signed-open-driver
  * added comments for requirements
* Fri Oct 18 2024 sndirsch@suse.com
- latest change hardcoded to 555.42.06; we no longer need this
  for 560
* Fri Oct 18 2024 sndirsch@suse.com
- nv-prefer-signed-open-driver:
  * added specicic versions of cuda-drivers/cuda-drivers-xxx as
    preconditions for requiring specific version of
    nvidia-compute-G06
* Fri Oct 18 2024 sndirsch@suse.com
- nv-prefer-signed-open-driver:
  * no longer require a specific version of
    nvidia-open-driver-G06-signed-cuda-kmp, so it can select the
    correct open driver KMP matching the cuda-runtime version
- cuda-flavor:
  * added nvidia-compute-G06 = %%version to preconditions for
    requiring kernel-firmware-nvidia-gspx-G06, since
    nvidia-compute-utils-G06 does not have a version-specific
    requires on nvidia-compute-G06
* Wed Oct 16 2024 sndirsch@suse.com
- cuda-flavor:
  * require kernel-firmware-nvidia-gspx-G06 instead of
    kernel-firmware-nvidia-gspx-G06-cuda (which provides also
    kernel-firmware-nvidia-gspx-G06)
  * trigger removal of driver modules also on
    kernel-firmware-nvidia-gspx-G06
* Wed Oct 16 2024 sndirsch@suse.com
- no longer hard-require kernel firmware package, but install it
  automatically once nvidia-compute-utils-G06 gets installed
- trigger removal of driver modules with non-existing or wrong
  firmware when (new) firmware gets installed
* Sat Sep 21 2024 sndirsch@suse.com
- Update to 550.120 (boo#1230779)
  * Fixed a bug that could cause kernel crashes upon attempting
    KMS operations through DRM when nvidia_drm was loaded with
    modeset=0.
- aarch64-TW-buildfix.patch
  * fixes build on aarch64 with latest TW kernel
* Wed Sep 11 2024 sndirsch@suse.com
- CUDA build: removed entries from pci_ids-555.42.06 since this is
  doing more harm than benefit (bsc#1230368)
* Mon Sep  9 2024 sndirsch@suse.com
- For CUDA (preamble file):
  * added: Provides: nvidia-open-driver-G06-signed-cuda-kmp-$flavor = %%version
    which is needed for 'zypper install <package> = <version>'
  * added: Provides/Conflicts: nvidia-open-driver-G06-signed-kmp-$flavor = %%version
    useful for containers
* Wed Aug 28 2024 sndirsch@suse.com
- reverted CUDA update version to 560.x.y due to changes in CUDA
  repository with CUDA 12.6/560.x.y drivers
- kernel-6.10.patch:
  * fixes build of 555.42.06 against Kernel 6.10
* Sun Aug 25 2024 sndirsch@suse.com
- For CUDA update version to 560.35.03
* Mon Aug 12 2024 sndirsch@suse.com
- Update to 550.107.02 (boo#1229716)
* Sat Aug 10 2024 sndirsch@suse.com
- For CUDA update version to 560.28.03
* Tue Jul 23 2024 sndirsch@suse.com
- better summary and description for KMP
* Thu Jul 11 2024 eich@suse.com
- Update to version 555.42.06 for CUDA. This tag has become
  available in github, now.
* Tue Jul  9 2024 sndirsch@suse.com
- Update to 550.100 (boo#1227575)
  * Fixed a bug that caused OpenGL triple buffering to behave like
    double buffering.
* Mon Jul  8 2024 eich@suse.com
- Use macro which is set during build but not when running
  `osc service run download_files` to make sure both source versions
  are visible for download. This way, only the correct source
  tarball will be included in the source package of its respective
  flavor but both can be downloaded (updated) simultaniously.
* Fri Jul  5 2024 sndirsch@suse.com
- make buildservice happy; all sources need to be mentioned as such
  in specfile
* Thu Jul  4 2024 eich@suse.com
- To avoid issues with missing dependencies when no CUDA repo
  is present make the dependecy to nvidia-compute-G06 conditional.
- CUDA is not available for Tumbleweed, exclude the build of the
  cuda flavor.
* Thu Jul  4 2024 sndirsch@suse.com
- preamble: let the -cuda flavor KMP require the -cuda flavor
  firmware
* Wed Jul  3 2024 eich@suse.com
- Add a second flavor for building the kernel module versions
  used by CUDA. The kmp targetting CUDA contains '-cuda' in
  its name to track its versions separately from the graphics
  kmp. (bsc#1227417)
- Provide the meta package nv-prefer-signed-open-driver to
  make sure the latest available SUSE-build open driver is
  installed - independent of the latest available open driver
  version in he CUDA repository.
  Rationale:
  The package cuda-runtime provides the link between CUDA and
  the kernel driver version through a
  Requires: cuda-drivers >= %%version
  This implies that a CUDA version will run withany kernel driver
  version equal or higher than a base version.
  nvidia-compute-G06 provides the glue layer between CUDA and
  a specific version of he kernel driver both by providing
  a set of base libraries and by requiring a specific kernel
  version. 'cuda-drivers' (provided by nvidia-compute-utils-G06)
  requires an unversioned nvidia-compute-G06. With this, the
  resolver will install the latest available and applicable
  nvidia-compute-G06.
  nv-prefer-signed-open-driver then represents the latest available
  open driver version and restricts the nvidia-compute-G06 version
  to it. (bsc#1227419)
* Tue Jun  4 2024 sndirsch@suse.com
- Security Update 550.90.07 (boo#1223356) [CVE-2024-0090,
  CVE-2024-0091, CVE-2024-0092]
* Mon Apr 29 2024 sndirsch@suse.com
- Update to 550.78
  * addresses boo#1223454
* Wed Apr 17 2024 sndirsch@suse.com
- Update to 550.76
  * addresses boo#1222972
* Tue Mar 19 2024 sndirsch@suse.com
- Update to 550.67
- rename pci_ids-unsupported* to pci_ids-supported* files
* Wed Feb 28 2024 sndirsch@suse.com
- let's provide/obsolete nvidia-open-driver-G06 instead of
  nvidia-open-driver-G06-kmp since older versions still had
  conflicts to nvidia-open-driver-G06-kmp ...
* Sat Feb 24 2024 sndirsch@suse.com
- Update to 550.54.14
  * Added vGPU Host and vGPU Guest support. For vGPU Host, please
    refer to the README.vgpu packaged in the vGPU Host Package for
    more details.
- supersedes the following patches:
  * 0001-Don-t-override-INSTALL_MOD_DIR.patch
  * kernel-6.7.patch
* Fri Feb 23 2024 sndirsch@suse.com
- re-enable build of -azure kernel flavor; syntax check was wrong
* Thu Feb 22 2024 sndirsch@suse.com
- remove conflicts to nvidia-open-driver-G06-kmp, since it's now
  provided instead (OMG!); add obsoletes to it as well to make
  sure it gets replaced (bsc#1220196)
* Thu Feb 22 2024 dimstar@opensuse.org
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Mon Feb 19 2024 sndirsch@suse.com
- kernel-syms-azure is not available on ALP
* Thu Feb  8 2024 sndirsch@suse.com
- provide nvidia-open-driver-G06-kmp = %%version (jsc#PED-7117)
  * this makes it easy to replace the package from nVidia's
    CUDA repository with this presigned package
* Thu Jan 25 2024 sndirsch@suse.com
- splitted up 61-nvidia-$flavor.conf to 59-nvidia-$flavor.conf
  and 61-nvidia-$flavor.conf, because 'install' line cannot be
  overwritten with higher config number ...
* Thu Jan 25 2024 sndirsch@suse.com
- mistakenly moved dracut config file from 60-nvidia-%%1.conf to
  61-nvidia-%%1.conf --> reverted!
* Thu Jan 25 2024 sndirsch@suse.com
- switched from 60-nvidia-$flavor.conf to 61-nvidia-$flavor.conf in
  modprobe.d to resolve conflict with older package, which can be
  installed in parallel
* Wed Jan 24 2024 sndirsch@suse.com
- kernel-6.7.patch
  * fixes build against kernel 6.7 (boo#1219117)
* Tue Jan  9 2024 sndirsch@suse.com
- create /run/udev/static_node-tags/uaccess/nvidia${devid} symlinks
  also during modprobing the nvidia module; this changes the issue
  of not having access to /dev/nvidia${devid}, when gfxcard has
  been replaced by a different gfx card after installing the driver
* Tue Dec  5 2023 sndirsch@suse.com
- fix typo in changelog:
  * NVreg_OpenRMEnableSupporteGpus -> NVreg_OpenRmEnableUnsupportedGpus
    (boo#1215981, comment#33)
* Thu Nov 23 2023 sndirsch@suse.com
- Update to 545.29.06
* Wed Nov 22 2023 sndirsch@suse.com
- no longer try to overwrite NVreg_OpenRmEnableUnsupportedGpus driver
  option setting; apparently it's ignored by the driver (boo#1215981,
  comment#26)
* Tue Nov 21 2023 sndirsch@suse.com
- use different modprobe.d config file to resolve conflict with
  older driver package (boo#1217370); overwrite
  NVreg_OpenRmEnableUnsupportedGpus driver option setting (disable it),
  since letting it enabled is supposed to break booting (boo#1215981,
  comment#23)
* Mon Nov 13 2023 sndirsch@suse.com
- Update to 545.29.02
- added fbdev=1 option for nvidia-drm module, which gives us a proper
  framebuffer console now ...
- nosimplefb kernel option no longer needed with usage of nvidia-drm's
  fbdev=1 option
- nvidia's NVreg_OpenRmEnableUnsupportedGpus=1 option no longer
  needed; GeForce and Workstation GPUs now officially supported
- support added for H100/H800 GPUs (Hopper)
* Fri Nov  3 2023 sndirsch@suse.com
- cleanup; sle12 no longer supported
* Wed Nov  1 2023 sndirsch@suse.com
- Update to version 535.129.03
* Tue Oct 17 2023 sndirsch@suse.com
- cleanup: get rid of possibiliy to hardcode pci list; it's no
  longer required anyway; secureboot signing has been fixed ...
- removed pci-table.patch
* Wed Oct 11 2023 eich@suse.com
- Add a devel package so other modules can be built against this
  one. [jira#PED-4964]
* Wed Oct 11 2023 sndirsch@suse.com
- disabled build of nvidia-peermem module; it's no longer needed
  and never worked anyway (it was only a stub) [boo#1211892]
* Mon Oct  2 2023 sndirsch@suse.com
- preamble: added conflict to nvidia-gfxG05-kmp to prevent users
  from accidently installing conflicting proprietary kernelspace
  drivers from CUDA repository
* Fri Sep 22 2023 sndirsch@suse.com
- Update to version 535.113.01
* Tue Sep  5 2023 sndirsch@suse.com
- kmp-post.sh/kmp-postun.sh:
  * add/remove nosimplefb=1 kernel option in order to fix Linux
    console also on sle15-sp6/Leap 15.6 kernel, which will come
    with simpledrm support
* Mon Aug 28 2023 sndirsch@suse.com
- Update to version 535.104.05
* Tue Jul 25 2023 sndirsch@suse.com
- require one-time renamed package kernel-firmware-nvidia-gspx-G06
  from now on (boo#1212724)
* Mon Jul 24 2023 lnussel@suse.com
- Replace transitional %%usrmerged macro with regular version check (boo#1206798)
* Wed Jul 19 2023 sndirsch@suse.com
- Update to version 535.86.05
* Fri Jun 16 2023 sndirsch@suse.com
- _constraints: 4GB wasn't enough; trying 8GB now ...
* Fri Jun 16 2023 sndirsch@suse.com
- _constraints: reserve 4GB of disk space for building in the hope
  that this will be also sufficient when building for sle15-sp5
* Thu Jun 15 2023 sndirsch@suse.com
- Update to version 535.54.03
* Tue May  9 2023 sndirsch@suse.com
- Update to version 525.116.04
* Tue Apr 25 2023 sndirsch@suse.com
-  Update to version 525.116.03
* Thu Mar 30 2023 sndirsch@suse.com
- Update to version 525.105.17
* Fri Feb 10 2023 sndirsch@suse.com
- no longer use %%hardcode_pci_list macro on sle15/Leap15, since the
  issue with generating wrong PCI ID modaliases for Supplements
  has been fixed meanwhile also in pesign-obs-integration package
  for sle15/Leap15 (boo#1207520)
* Wed Feb  8 2023 sndirsch@suse.com
- Update to version 525.89.02
* Mon Jan 30 2023 sndirsch@suse.com
- no longer use %%hardcode_pci_list macro on TW, since the issue
  with generating wrong PCI ID modaliases for Supplements
  has been fixed now in pesign-obs-integration package for TW
  (boo#1207520)
* Sun Jan 29 2023 sndirsch@suse.com
- introduce %%hardcode_pci_list macro for hardcoding PCI ID
  modaliases for Supplements; make it default to *temporarily*
  workaround boo#1207520
  * TW: enable only officially supported headless GPUs!
  * Leap/sle: enable all Turing and Ampere GPUs and set the
    appropriate modprobe.d option, so we can at least begin
    testing on sle15-sp5 ...
- adds pci-table.patch, generati-pci-table.sh
* Wed Jan 25 2023 sndirsch@suse.com
- added pesign-copy-sources, pesign-spec-macros, which are needed
  to fix repackaging step required for securebooot signing kernel
  modules (boo#1207520)
- pesign-spec-macros: used for defining RPM macros; here:
  %%define __kmp_supplements %%_sourcedir/my-find-supplements \
    %%_sourcedir/pci_ids-%%{version}
- pesign-copy-sources: sources needed by the RPM macros above;
  here: pci_ids-%%{version}, my-find-supplements
- all above needs changes for pesign-obs-integration first
  (SR#1060443)
* Tue Jan 24 2023 sndirsch@suse.com
- added conflicts to nvidia-driver-G06-kmp package (boo#1207495)
* Thu Jan 19 2023 sndirsch@suse.com
- Update to version 525.85.05
  * Fix build problems with Clang 15.0, #377 by @ptr1337
* Thu Jan 19 2023 sndirsch@suse.com
- require "group(video)"
* Thu Jan 19 2023 sndirsch@suse.com
- set options for nvidia kernel module via modprobe install script;
  no longer adjusting of nvidia's NVreg_DeviceFileGID option in
  modprobe.d file needed in %%post
* Thu Jan 19 2023 sndirsch@suse.com
- package the modprobe.d file as a sample in
  /usr/lib/nvidia-open-driver-G06-signed; then adjust GUID of
  video group for nvidia's NVreg_DeviceFileGID option and write the
  result to /etc/modprobe.d, i.e. no longer touch a packaged
  modprobe.d file below /usr
* Thu Jan 19 2023 sndirsch@suse.com
- set group id for nvidia's NVreg_DeviceFileGID option already
  during build, since it's not allowed to edit modprobe.d files
  during %%post
* Wed Jan 18 2023 sndirsch@suse.com
- added pci_ids-unsupported-525.78.01/pci_ids-unsupported as sources
  to specfile
* Wed Jan 18 2023 sndirsch@suse.com
- added empty %%changelog section to specfile
* Wed Jan 18 2023 sndirsch@suse.com
- implements jsc#PED-2658
* Mon Jan  9 2023 sndirsch@suse.com
- require kernel-firmware-nvidia-gsp-G06 (with suffix -G06!)
* Mon Jan  9 2023 sndirsch@suse.com
- Update to version 525.78.01
  * adds alpha support for
    + NVIDIA GeForce RTX 3050
    + NVIDIA GeForce RTX 4090
    + NVIDIA RTX 6000 Ada Generation
    + NVIDIA L40
    + NVIDIA GeForce RTX 4080
    + NVIDIA GeForce RTX 4070 Ti
* Wed Jan  4 2023 sndirsch@suse.com
- renamed package to nvidia-open-driver-G06-signed due to package
  redesign
* Mon Nov 28 2022 sndirsch@suse.com
- Update to version 525.60.11
* Wed Nov 23 2022 sndirsch@suse.com
- set NVreg_PreserveVideoMemoryAllocations kernel option now
  needed for GNOME Wayland (gdm) since
    commit 51181871e9db716546e9593216220389de0d8b03
    Author: Ray Strode <rstrode@redhat.com>
    Date:   Fri Mar 4 14:11:03 2022 -0500
    data: Disable wayland on nvidia if suspend is broken
* Mon Nov 14 2022 sndirsch@suse.com
- added /etc/dracut.conf.d/60-nvidia-$flavor.conf in order to
  omit nvidia modules in initrd, which apparently were added
  automatically - apart from nvidia-uvm module; related to
  boo#1173733
* Fri Nov 11 2022 sndirsch@suse.com
- Update to 525.53
  * GSP firmware is now distributed as multiple firmware files:
    this release has gsp_tu10x.bin and gsp_ad10x.bin replacing
    gsp.bin from previous releases.
    + Each file is named after a GPU architecture and supports
    GPUs from one or more architectures. This allows GSP
    firmware to better leverage each architecture's
    capabilities.
    + The .run installer will continue to install firmware to
    /lib/firmware/nvidia/<version> and the nvidia.ko kernel
    module will load the appropriate firmware for each GPU at
    runtime.
  * Add support for IBT (indirect branch tracking) on supported
    platforms, #256 by @rnd-ash
  * Return EINVAL when [failing to] allocating memory,
    [#280] by @YusufKhan-gamedev
  * Fix various typos in nvidia/src/kernel, #16 by
    @alexisgeoffrey
  * Added support for rotation in X11, Quadro Sync, Stereo,
    and YUV 4:2:0 on Turing.
* Tue Oct 18 2022 sndirsch@suse.com
- (build-)require perl-Bootloader due to pbl usage in %%post(-un)
* Tue Oct 18 2022 sndirsch@suse.com
- kmp-post.sh/kmp-postun.sh:
  * add/remove nosimplefb=1 kernel option in order to fix Linux
    console on TW kernel, which comes with simpledrm support
* Sat Oct  8 2022 sndirsch@suse.com
- Update to 515.76
  * Improved compatibility with new Linux kernel releases
  * Fixed possible excessive GPU power draw on an idle X11 or
    Wayland desktop when driving high resolutions or refresh rates
* Wed Aug  3 2022 sndirsch@suse.com
- added pci_ids-unsupported -> pci_ids-unsupported-515.65.01
  symlink to which I can refer from blog
* Tue Aug  2 2022 sndirsch@suse.com
- Update to 515.65.01
  * Collection of minor fixes to issues, #6 by @Joshua-Ashton
  * Remove unnecessary use of acpi_bus_get_device().
* Tue Jul 19 2022 gmbr3@opensuse.org
- Force CC to gcc to avoid compiler differs warnings
* Tue Jul 19 2022 sndirsch@suse.com
- json-to-pci-id-list.py
  * added new Python script by Tamara Schmitz which is being used
  now to parse supported-gpus.json in order to create the PCI ID
  list 'pci_ids-unsupported-<version>'
* Mon Jul 18 2022 sndirsch@suse.com
- pci_ids-unsupported-515.57
  * currently unsupported devices (Turing and later, which needs
    NVreg_OpenRmEnableUnsupportedGpus=1 kernel option; Alpha Quality!)
* Thu Jul 14 2022 sndirsch@suse.com
- define %%kernel_module_directory macro on older distros in order
  to fix build on Leap 15.3(GA)/sle 15 SP3(GA)
* Thu Jun 30 2022 sndirsch@suse.com
- update to 515.57
  * Backtick is deprecated, #273 by @arch-user-france1
* Fri Jun 17 2022 gmbr3@opensuse.org
- Revert last change and use default CA [pesign-obs-integration
  and kernel-source docs are incorrect]
* Thu Jun 16 2022 gmbr3@opensuse.org
- Create uefi cert package
* Wed Jun 15 2022 gmbr3@opensuse.org
- Sign the kernel modules and compress them
* Wed Jun 15 2022 sndirsch@suse.com
- don't buildrequire azure on aarch64; no such kernel flavor
  available on aarch64
* Thu Jun  9 2022 sndirsch@suse.com
- move cuda-drivers = %%version provide to nvidia-computeG0X, which
  then again requires nvidia-gfxG0X-kmp or nvidia-open-gfxG0X-kmp
  respectively
* Wed Jun  8 2022 sndirsch@suse.com
- preamble: provide cuda-drivers = %%version, so you can just
  install 'cuda' meta package to install CUDA stack
  (cuda --> cuda-11-7 --> cuda-runtime-11-7 --> cuda-drivers >= 515.43.04)
  from https://developer.download.nvidia.com/compute/cuda/repos/opensuse15/x86_64/
* Tue Jun  7 2022 sndirsch@suse.com
- preamble: added Conflicts to nvidia-gfxG06-kmp
* Tue May 31 2022 sndirsch@suse.com
- update to 515.48.07
  * List of compatible GPUs in README.md.
  * Fix various README capitalizations, #8 by @lx-is
  * Automatically tag bug report issues, #15 by @thebeanogamer
  * Improve conftest.sh Script, #37 by @Nitepone
  * Update HTTP link to HTTPS, #101 by @alcaparra
  * moved array sanity check to before the array access, #117 by @RealAstolfo
  * Fixed some typos, #122 by @FEDOyt
  * Fixed capitalization, #123 by @keroeslux
  * Fix typos in NVDEC Engine Descriptor, #126 from @TrickyDmitriy
  * Extranous apostrohpes in a makefile script [sic], #14 by @kiroma
  * HDMI no audio @ 4K above 60Hz, #75 by @adolfotregosa
  * dp_configcaps.cpp:405: array index sanity check in wrong place?, #110 by @dcb314
  * NVRM kgspInitRm_IMPL: missing NVDEC0 engine, cannot initialize GSP-RM, #116 by @kfazz
  * ERROR: modpost: "backlight_device_register" [...nvidia-modeset.ko] undefined, #135 by @sndirsch
  * aarch64 build fails, #151 by @frezbo
- supersedes backlight-workaround.patch
* Thu May 19 2022 gmbr3@opensuse.org
- Set mno-outline-atomics to fix libgcc issues on aarch64
* Thu May 19 2022 sndirsch@suse.com
- preamble: require kernel-firmware-nvidia-gsp package for nvidia's
  versioned "gsp.bin" fimrware
* Thu May 19 2022 sndirsch@suse.com
- enable build also for aarch64
* Thu May 19 2022 sndirsch@suse.com
- improved summary and description
* Thu May 19 2022 sndirsch@suse.com
- modprobe.nvidia.install
  * install script when the "nvidia" module is being loaded; needed
    for creating devices
- specfile
  * filled modprobe.d config file (options and install script)
* Thu May 19 2022 sndirsch@suse.com
- kmp-post.sh/kmp-postun.sh
  * additional code for %%post/%%postun scriptlets to create nvidia
    devices
- specfile: adjust %%kernel_module_package macro appropriately
* Tue May 17 2022 sndirsch@suse.com
- added kmp-filelist
- adding an empty modprobe.d config file (to be filled later)
* Tue May 17 2022 sndirsch@suse.com
- added hardware supplements
  * added my-find-supplements, pci_ids-515.43.04
  * changes in specfile to generate the hardware supplements from
    pci_ids-515.43.04 via my-find-supplements
* Tue May 17 2022 tiwai@suse.com
- Set SYSSRC and SYSOUT for building with proper kernel source tree
  for each flavor
- Exclusive build for x86_64
- backlight-workaround.patch:
  workaround for a build failure with azure flavor
- persistent-nvidia-id-string.patch:
  make persistent nvidia id string for reproducible builds
* Fri May 13 2022 sndirsch@suse.com
- switched to a known license to fix build:  MIT/GPLv2 --> GPL-2.0 and MIT
* Fri May 13 2022 patrik.jakobsson@suse.com
- 0001-Don-t-override-INSTALL_MOD_DIR.patch
  * Make sure INSTALL_MOD_DIR from our spec-file is honoured
- Make the default flavor build. Not sure how to get other flavors to build.
* Thu May 12 2022 sndirsch@suse.com
- created package
  * build still fails completely
  * more things are missing
